@@ -2,10 +2,14 @@
 //
 // SPDX-License-Identifier: MIT
 
+#![doc = include_str!("../README.md")]
 #![warn(clippy::all, clippy::pedantic, clippy::nursery, clippy::cargo)]
 #![allow(clippy::module_name_repetitions, clippy::must_use_candidate)]
 
-pub mod error;
-pub mod expression;
+mod error;
+mod expression;
 mod inner_variant;
-mod parse;
+mod parser;
+
+pub use error::SpdxExpressionError;
+pub use expression::SPDXExpression;
